
# Slot: related mappings


A list of terms from different schemas or terminology systems that have related meaning.

URI: [linkml:related_mappings](https://w3id.org/linkml/related_mappings)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [mappings](mappings.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:relatedMatch |

